{
  config,
  pkgs,
  inputs,
  ...
}: {
  imports = [
    inputs.home-manager.darwinModules.default
    ../../modules/nix-darwin/system.nix
    #../../modules/nixos/postgres.nix
    ../../modules/nix-darwin/aerospace.nix
  ];

  nixpkgs.hostPlatform = "aarch64-darwin";
  nixpkgs.config.allowUnfree = true;
  nixpkgs.config.allowBroken = true;

  nix.nixPath = ["nixpkgs=${inputs.nixpkgs}"];

  networking.hostName = "macbook";

  nix.settings = {
    trusted-users = ["mthomson"];

    substituters = [
      "https://cache.nixos.org"
      "https://nix-community.cachix.org"
    ];

    trusted-public-keys = [
      "nix-community.cachix.org-1:mB9FSh9qf2dCimDSUo8Zy7bkq5CX+/rkCWyvRCYg3Fs="
    ];
  };

  users.users.mthomson = {
    home = "/Users/mthomson";
  };

  nix.settings.experimental-features = ["nix-command" "flakes"];

  environment.systemPackages = with pkgs; [
    man-pages
    man-pages-posix
    (python3.withPackages (python-pkgs: with python-pkgs; [
      websocket-client
      websockets
    ]))
  ];

  services = {
    # skhd = {
    #   enable = true;
    #   skhdConfig = ''
    #     cmd - return : kitty
    #   '';
    # };
  };

  home-manager = {
    extraSpecialArgs = {inherit inputs;};
    useGlobalPkgs = true;
    useUserPackages = true;
    backupFileExtension = "backup";
    users = {
      mthomson = import ./home.nix;
    };
  };

  nixpkgs.config.packageOverrides = pkgs: {
    emacs = pkgs.emacs.override { withNativeCompilation = false; };
  };

  system.stateVersion = 5;

  # fix for this: https://github.com/LnL7/nix-darwin/issues/1346
  ids.gids.nixbld = 30000;
  nix.package = pkgs.nix;
}
